@@ -40,15 +40,30 @@ def runserver(host, port):
 
 @cmd.command()
 @click.option('--last-date', default=False)
-def sync(last_date):
+@click.option('--product-ese', is_flag=True, default=False)
+def sync(last_date, product_ese):
     """Mise à jour de la liste des clients Business ainsi que de leurs \
     relevés de consommation superieur a une date."""
-    products = Product.all()
-    for product in products:
-        product.update_customers()
-        f = partial(core.update_customer_cdr, last_date)
-        with Pool(processes=2) as pool:
-            pool.map(f, product.customers)
+    if not product_ese:
+        click.echo('not product_ese')
+        products = Product.all()
+        click.echo(products)
+        for product in products:
+            product.update_customers()
+            f = partial(core.update_customer_cdr, last_date)
+            with Pool(processes=2) as pool:
+                click.echo(product.customers)
+                pool.map(f, product.customers)
+    else:
+        click.echo('product_ese')
+        product_eses = Product.all_ese()
+        for product in product_eses:
+            click.echo(product)
+            product.update_customers(product_ese=product_ese)
+            f = partial(core.update_customer_cdr, last_date)
+            with Pool(processes=2) as pool:
+                click.echo(product.customers_ese)
+                pool.map(f, product.customers_ese)
 
 
 @cmd.command()
@@ -104,68 +119,185 @@ def notify(start_date, stop_date):
 
 
 @cmd.command()
-def reconciled():
-    """compare les clients fupe dans aiguillier et api-fup"""
-    dataset_reconcile = tablib.Dataset()
-    message = ''
-    customers = []
-    dataset_reconcile.headers = [
-        'customers',
-        'fup_aiguillier',
-        'fup_api'
-        ]
+@click.option('--product', is_flag=True, default=False)
+def reconciled(product):
+    if not product:
+        """compare les clients fupe dans aiguillier et api-fup"""
+        subject = '[blueline] Reconcile FUP'
+        dataset_reconcile = tablib.Dataset()
+        message = ''
+        customers = []
+        dataset_reconcile.headers = [
+            'customers',
+            'fup_aiguillier',
+            'fup_api'
+            ]
 
-    response = REST_CLIENT.get(
-        '/fup',
-        auth=(
-            CONFIG['AIGUILLIER']['username'],
-            CONFIG['AIGUILLIER']['password']
+        response = REST_CLIENT.get(
+            '/fup',
+            auth=(
+                CONFIG['AIGUILLIER']['username'],
+                CONFIG['AIGUILLIER']['password']
+                )
             )
-        )
-    infos = response['content']['fup']
-    infos_aiguillier = [
-                            info['name'].lower()
-                            for info in infos
-                            if info['name']
-                            ]
-    url = core.database_url(**FUPDB_CREDENTIALS)
-    with records.Database(url) as db:
-        sql = (
-            "SELECT * FROM fup AS data "
-            "WHERE datetime = "
-            "(SELECT MAX(datetime) FROM fup "
-            "WHERE customer = data.customer) "
-            "and status = True"
+        infos = response['content']['fup']
+        infos_aiguillier = [
+                                info['name'].lower()
+                                for info in infos
+                                if info['name']
+                                ]
+        url = core.database_url(**FUPDB_CREDENTIALS)
+        with records.Database(url) as db:
+            sql = (
+                "SELECT * FROM fup AS data "
+                "WHERE datetime = "
+                "(SELECT MAX(datetime) FROM fup "
+                "WHERE customer = data.customer) "
+                "and status = True"
+                )
+            rows = db.query(sql)
+            infos_api = [row.customer for row in rows]
+        customers = [x for x in infos_aiguillier if x not in customers]
+        for info in infos_api:
+            if info not in customers:
+                customers.append(info)
+        for customer in customers:
+            result_aiguillier = 'NO'
+            result_api = 'NO'
+            if customer in infos_aiguillier:
+                result_aiguillier = 'YES'
+            if customer in infos_api:
+                result_api = 'YES'
+            dataset_reconcile.append(
+                [
+                    customer,
+                    result_aiguillier,
+                    result_api
+                    ]
+                )
+        message += str(dataset_reconcile)
+    else:
+        bool_error = False
+        dataset_reconcile = tablib.Dataset()
+        message = ''
+        customers = {}
+        dataset_reconcile.headers = [
+            'customers',
+            'product_aiguillier',
+            'refnum_aiguillier',
+            'product_bluebase',
+            'refnum_bluebase',
+            'product_gateway',
+            'refnum_gateway'
+            ]
+        products = Product.all()
+        click.echo(products)
+        """ customer from aiguillier """
+        for product in products:
+            customers_api = product.get_customers_aiguillier()
+            customers.update(customers_api)
+        """ customer from 4d """
+        for product in products:
+            customers_bluebase = product.get_customers_bluebase()
+            for customer, infos in customers_bluebase.items():
+                if customer.lower() not in customers.keys():
+                    click.echo('customer 4D {}'.format(
+                        customer
+                        ))
+                    customers.update({
+                        customer.lower(): {
+                            'product': 'unknown',
+                            'refnum': 'unknown',
+                            'product_bluebase': infos['product'],
+                            'refnum_bluebase': infos['refnum']
+                            }
+                        })
+                else:
+                    customers[customer.lower()].update({
+                        'product_bluebase': infos['product'],
+                        'refnum_bluebase': infos['refnum']
+                        })
+        """ customer from api_gateway"""
+        for product in products:
+            customers_gateway = product.get_customers_gateway()
+            for customer, infos in customers_gateway.items():
+                if customer.lower() not in customers.keys():
+                    click.echo('customer gateway {}'.format(
+                        customer
+                        ))
+                    customers.update({
+                        customer.lower(): {
+                            'product': 'unknown',
+                            'refnum': 'unknown',
+                            'product_gateway': infos['product'],
+                            'refnum_gateway': infos['refnum']
+                            }
+                        })
+                else:
+                    customers[customer.lower()].update({
+                        'product_gateway': infos['product'],
+                        'refnum_gateway': infos['refnum']
+                        })
+        customers = sorted(
+            customers.items(),
+            key=lambda x: x[1]['product']
             )
-        rows = db.query(sql)
-        infos_api = [row.customer for row in rows]
-    customers = [x for x in infos_aiguillier if x not in customers]
-    for info in infos_api:
-        if info not in customers:
-            customers.append(info)
-    for customer in customers:
-        result_aiguillier = 'NO'
-        result_api = 'NO'
-        if customer in infos_aiguillier:
-            result_aiguillier = 'YES'
-        if customer in infos_api:
-            result_api = 'YES'
-        dataset_reconcile.append(
-            [
-                customer,
-                result_aiguillier,
-                result_api
-                ]
-            )
-    message += str(dataset_reconcile)
+        for customer, infos in customers:
+            product = infos.get('product', 'unknown')
+            refnum = infos.get('refnum', 'unknown')
+            refnum_gateway = infos.get('refnum_gateway', 'unknown')
+            product_gateway = infos.get('product_gateway', 'unknown')
+            refnum_bluebase = infos.get('refnum_bluebase', 'unknown')
+            product_bluebase = infos.get('product_bluebase', 'unknown')
+            condition = (
+                product_gateway != product
+                or
+                refnum_gateway != refnum
+                or
+                product_bluebase.lower() != product
+                or
+                refnum_bluebase != refnum
+                )
+            if condition:
+                bool_error = True
+                dataset_reconcile.append(
+                    [
+                        customer.lower(),
+                        product.lower(),
+                        refnum,
+                        product_bluebase.lower(),
+                        refnum_bluebase,
+                        product_gateway.lower(),
+                        refnum_gateway
+                        ]
+                    )
+        if bool_error:
+            subject = '[blueline] Incohérence Reconciliation customer'
+            message += str(dataset_reconcile)+"\n"
+        else:
+            subject = '[blueline] Succes Reconciliation customer'
+            message += "Succes"
+    with open('/tmp/details_reconciliation.csv', 'w') as f:
+        content = dataset_reconcile.export('csv', delimiter=';')
+        f.write(content)
     # envoyer msg
     email = CONFIG['ALERT']['to_1']
     content = MIMEText(message, 'plain', 'utf-8')
-    msg = MIMEMultipart()
-    msg['Subject'] = '[blueline] Reconcile FUP'
+    attachment = MIMEBase('text', 'csv')
+    fp = open('/tmp/details_reconciliation.csv', 'rb')
+    attachment.set_payload(fp.read())
+    fp.close()
+    attachment.add_header(
+        'Content-Disposition',
+        'attachment',
+        filename='details_reconciliation.csv'
+        )
+    msg = MIMEMultipart('related')
+    msg['Subject'] = subject
     msg['From'] = CONFIG['ALERT']['from']
     msg['To'] = email
     msg.attach(content)
+    msg.attach(attachment)
     s = smtplib.SMTP('localhost')
     s.sendmail(
         CONFIG['ALERT']['from'],
@@ -224,7 +356,8 @@ def apply(for_real, send_mail, random):
             'download_national',
             'upload_national',
             'total',
-            'status'
+            'status',
+            'date'
             ]
         products = sorted([i for i in result], reverse=True)
         for product in products:
@@ -285,7 +418,8 @@ def apply(for_real, send_mail, random):
                             conso['national']['octets_in'],
                             conso['national']['octets_out'],
                             total,
-                            policy_status
+                            policy_status,
+                            datetime.now().date().strftime('%d/%m/%Y')
                             ]
                         )
                     if policy_status is True:
