@@ -238,7 +238,16 @@ def get_customer_consumption(uuid):
         description: Erreur interne
     """
     try:
-        customer = lib_customer.Customer(uuid)
+        product_out_fup = request.args.get('product_out_fup', None)
+        if product_out_fup.lower() == 'true':
+            kwargs = {
+                'table_customer': 'customer_ese',
+                'table_cdr': 'cdr_ese'
+            }
+            customer = lib_customer.Customer(uuid, **kwargs)
+        else:
+            product_out_fup = False
+            customer = lib_customer.Customer(uuid)
     except ValueError:
         return not_found(
             message="Le client {} n'existe pas".format(uuid),
@@ -279,7 +288,12 @@ def get_customer_consumption(uuid):
                         ),
                     service_code=SERVICE_CODE
                     )
-        infos = customer.get_cdr_summary(start.date(), stop.date(), True)
+        infos = customer.get_cdr_summary(
+            start.date(),
+            stop.date(),
+            True,
+            product_out_fup
+            )
         return jsonify(infos)
 
 # EOF
