@@ -77,6 +77,8 @@ def apply_product_policies(for_real, customer):
 
 def update_customer_cdr(last_date, customer):
     """Mise à jour des CDRs d'un client dans la base REDIS"""
-    customer.get_cdr_from_aiguillier(last_date=last_date)
+    customer.get_cdr_from_aiguillier(
+        last_date=last_date
+        )
 
 # EOF
