@@ -23,11 +23,20 @@ __all__ = [
 class Customer(object):
     """Un client internet est identifié par un nom, un refnum et un produit"""
 
-    def __init__(self, name):
+    def __init__(self, name, product_ese=False, **kwargs):
         self.name = name.lower()
         url = core.database_url(**FUPDB_CREDENTIALS)
         with records.Database(url) as db:
-            sql = "SELECT refnum, product FROM customer WHERE name=:name"
+            if kwargs:
+                self.table_customer = kwargs.get('table_customer')
+                self.table_cdr = kwargs.get('table_cdr')
+            else:
+                self.table_customer = 'customer'
+                self.table_cdr = 'cdr'
+            sql = (
+                "SELECT refnum, product FROM {}"
+                " WHERE name=:name"
+                ).format(self.table_customer)
             rows = db.query(sql, name=self.name)
             row = rows.first()
             if not row:
@@ -37,6 +46,7 @@ class Customer(object):
             else:
                 self.product = product.Product(row.product)
                 self.refnum = row.refnum
+            LOGS.logger.info(self.product)
 
     def __repr__(self):
         return '<Customer {name}>'.format(name=self.name)
@@ -50,6 +60,19 @@ class Customer(object):
             customers = [Customer(row.name) for row in rows]
         return customers
 
+    @staticmethod
+    def all_ese():
+        kwargs = {
+            'table_customer': 'customer_ese',
+            'table_cdr': 'cdr_ese'
+            }
+        url = core.database_url(**FUPDB_CREDENTIALS)
+        with records.Database(url) as db:
+            sql = "SELECT name FROM customer_ese"
+            rows = db.query(sql)
+            customers = [Customer(row.name, **kwargs) for row in rows]
+        return customers
+
     @property
     def fup_status(self):
         """Retourne le status FUP du client"""
@@ -74,9 +97,10 @@ class Customer(object):
         url = core.database_url(**FUPDB_CREDENTIALS)
         with records.Database(url) as db:
             sql = (
-                "UPDATE customer SET refnum=:refnum "
+                "UPDATE {} SET refnum=:refnum "
                 "WHERE name=:name"
-                )
+                ).format(self.table_customer)
+            LOGS.logger.info(sql)
             db.query(
                 sql,
                 refnum=refnum,
@@ -97,9 +121,10 @@ class Customer(object):
         url = core.database_url(**FUPDB_CREDENTIALS)
         with records.Database(url) as db:
             sql = (
-                "UPDATE customer SET product=:product "
+                "UPDATE {} SET product=:product "
                 "WHERE name=:name"
-                )
+                ).format(self.table_customer)
+            LOGS.logger.info(sql)
             db.query(
                 sql,
                 product=product_name,
@@ -187,8 +212,8 @@ class Customer(object):
         return result
 
     def get_cdr_from_aiguillier(self, last_date):
-        """Récupération des CDRs des 30 derniers jours
-        depuis l'API d'Aiguillier pour les clients business"""
+        """Récupération des CDRs a une date donné
+        depuis l'API d'Aiguillier pour les clients"""
         import time
         url = core.database_url(**FUPDB_CREDENTIALS)
         LOGS.logger.warn('last date {} de {}'.format(last_date, self.name))
@@ -321,9 +346,10 @@ class Customer(object):
                 result[date.strftime('%d%m%Y')].append(values)
             with records.Database(url) as db:
                 sql = (
-                    "DELETE FROM cdr WHERE customer=:name "
+                    "DELETE FROM {} WHERE customer=:name "
                     "AND datetime>=:start AND datetime<=:stop"
-                    )
+                    ).format(self.table_cdr)
+                LOGS.logger.info(sql)
                 db.query(
                     sql,
                     name=self.name,
@@ -333,20 +359,25 @@ class Customer(object):
         if params:
             with records.Database(url) as db:
                 sql = (
-                    "INSERT INTO cdr "
+                    "INSERT INTO {} "
                     "(customer, datetime, source, "
                     "octets_in, octets_out, product) "
                     "VALUES "
                     "(:name, :date_time, :source, "
                     ":octetsin, :octetsout, :product)"
-                    )
+                    ).format(self.table_cdr)
+                LOGS.logger.info(sql)
                 db.bulk_query(sql, *params)
         return result
 
-    def get_cdr(self, start=None, stop=None):
+    def get_cdr(self, start=None, stop=None, product_out_fup=False):
         """Récupération des données de conso d'un client business.
         Les dates sont des objets datetime.datetime
         """
+        if product_out_fup:
+            table_cdr = 'cdr_ese'
+        else:
+            table_cdr = 'cdr'
         if not start:
             start = (datetime.now() - timedelta(30))
         if not stop:
@@ -356,21 +387,23 @@ class Customer(object):
                 "La date de fin est inférieure à la date de début"
                 )
         LOGS.logger.info(
-            "Recuperation des CDRS de {customer} du {start} au {stop}".format(
+            "Recuperation des CDRS de {customer} "
+            "du {start} au {stop} dans table {table}".format(
                 customer=self.name,
                 start=start.strftime('%d%m%Y'),
-                stop=stop.strftime('%d%m%Y')
+                stop=stop.strftime('%d%m%Y'),
+                table=table_cdr
                 )
             )
         cdrs = {}
         url = core.database_url(**FUPDB_CREDENTIALS)
         with records.Database(url) as db:
             sql = (
-                "SELECT * FROM cdr "
+                "SELECT * FROM {} "
                 "WHERE customer=:name "
                 "AND datetime >= :start "
                 "AND datetime <= :stop "
-                )
+                ).format(table_cdr)
             rows = db.query(
                 sql,
                 name=self.name,
@@ -396,20 +429,27 @@ class Customer(object):
                 cdrs[date.strftime('%d%m%Y')] = list(data)
         return cdrs
 
-    def filter_cdrs_policy_wise(self, cdrs):
+    def filter_cdrs_policy_wise(self, cdrs, product_out_fup=False):
         """Suivant la politique de bon usage du produit réorganiser les cdrs"""
         result = []
-        for policy_name, policy in self.product.policies.items():
+        if product_out_fup:
+            dict_policies = self.product.no_policies.items()
+        else:
+            dict_policies = self.product.policies.items()
+        LOGS.logger.info(dict_policies)
+        for policy_name, policy in dict_policies:
             sources = {}
             info = {
                 'data_limit': policy['data_limit'],
                 'interval': policy['interval'],
-                'name': policy_name,
+                'name': str(policy_name),
                 'total': 0,
                 'octets_in': 0,
                 'octets_out': 0,
                 'details': []
                 }
+            if 'name_type' in policy.keys():
+                info['name_type'] = policy['name_type']
             intervals = []
             for interval in info['interval'].split('_'):
                 start, stop, day_start, day_stop = interval.split(',')
@@ -552,9 +592,11 @@ class Customer(object):
                     with records.Database(url) as db:
                         sql = (
                             "INSERT INTO fup "
-                            "(customer, product, policy, datetime, status) "
+                            "(customer, product, policy, datetime, status, "
+                            "conso) "
                             "VALUES "
-                            "(:name, :product, :policy, :date_time, :status)"
+                            "(:name, :product, :policy, :date_time, :status, "
+                            ":conso)"
                             )
                         db.query(
                             sql,
@@ -562,10 +604,9 @@ class Customer(object):
                             product=self.product.name,
                             policy=info['name'],
                             date_time=datetime.now(),
-                            status=True
+                            status=True,
+                            conso=str(info['total'])
                             )
-                    LOGS.logger.info(info['name'])
-                    LOGS.logger.info(info['period'])
                     REST_CLIENT.post(
                         '/fup',
                         auth=(
@@ -582,9 +623,11 @@ class Customer(object):
                     with records.Database(url) as db:
                         sql = (
                             "INSERT INTO fup "
-                            "(customer, product, policy, datetime, status) "
+                            "(customer, product, policy, datetime, status, "
+                            "conso) "
                             "VALUES "
-                            "(:name, :product, :policy, :date_time, :status)"
+                            "(:name, :product, :policy, :date_time, :status, "
+                            ":conso)"
                             )
                         db.query(
                             sql,
@@ -592,7 +635,8 @@ class Customer(object):
                             product=self.product.name,
                             policy=info['name'],
                             date_time=datetime.now(),
-                            status=False
+                            status=False,
+                            conso=str(info['total'])
                             )
                     REST_CLIENT.delete(
                         '/fup',
@@ -607,13 +651,19 @@ class Customer(object):
                         )
         return cdrs_by_policies
 
-    def get_cdr_summary(self, start=None, stop=None, daily_details=False):
+    def get_cdr_summary(
+            self,
+            start=None,
+            stop=None,
+            daily_details=False,
+            product_out_fup=None
+            ):
         sources = ['cache', 'national', 'internet']
         if not start:
             start = (datetime.now() - timedelta(30))
         if not stop:
             stop = (datetime.now() - timedelta(1))
-        cdrs = self.get_cdr(start, stop)
+        cdrs = self.get_cdr(start, stop, product_out_fup)
         sorted_cdrs = sorted(
             cdrs,
             key=lambda x: datetime.strptime(x, '%d%m%Y')
@@ -651,6 +701,21 @@ class Customer(object):
                         'total': octets_in + octets_out
                         }
                     )
+            details_sources = []
+            if total_by_source:
+                details_sources = [
+                    x['source'] for x in total_by_source
+                ]
+            for x in sources:
+                if x not in details_sources:
+                    total_by_source.append(
+                        {
+                            'source': x,
+                            'octets_in': 0.0,
+                            'total': 0.0,
+                            'octets_out': 0.0
+                        }
+                    )
             info = {
                 'date': date,
                 'total': daily_total,
@@ -659,7 +724,10 @@ class Customer(object):
                 'details': total_by_source,
                 'policy_wise': []
                 }
-            cdrs_by_policies = self.filter_cdrs_policy_wise({date: daily_data})
+            cdrs_by_policies = self.filter_cdrs_policy_wise(
+                {date: daily_data},
+                product_out_fup
+                )
             for i in cdrs_by_policies:
                 # comme c'est sur une seule journée
                 #  - i['details'] est de longueur 1
